Getting Started
===============

.. toctree::
   :maxdepth: 2

   readme


Documentation
=============

.. toctree::
   :maxdepth: 2

   modules

Contributing
===============

.. toctree::
   :maxdepth: 2

   contributing

Other
=====
.. toctree::
   :maxdepth: 1

   authors
   history

..
   (removed because it is contained in the new spinx style)
   Indices and tables
   ==================
   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
